@@ -208,7 +208,7 @@ static int set_up_rx_ring(AFPacket_Context_t *afpc, AFPacketInstance *instance)
     idx = 0;
     for (block = 0; block < instance->layout.tp_block_nr; block++)
     {
-        for (frame = 0; frame < instance->frames_per_block; frame++)
+        for (frame = 0; frame < instance->frames_per_block && idx < instance->layout.tp_frame_nr; frame++)
         {
             instance->ring[idx].begin = (uint8_t *) instance->buffer + (block * instance->layout.tp_block_size) + (frame * instance->layout.tp_frame_size);
             instance->ring[idx].hdr.raw = instance->ring[idx].begin;
@@ -570,7 +570,7 @@ static int afpacket_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr,
     dev = afpc->device;
     if (*dev == ':' || ((len = strlen(dev)) > 0 && *(dev + len - 1) == ':') || (config->mode == DAQ_MODE_PASSIVE && strstr(dev, "::")))
     {
-        snprintf(errbuf, errlen, "%s: Invalid interface specification: %s!", __FUNCTION__, afpc->device);
+        snprintf(errbuf, errlen, "%s: Invalid interface specification: '%s'!", __FUNCTION__, afpc->device);
         goto err;
     }
 
@@ -622,9 +622,9 @@ static int afpacket_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr,
     }
 
     /* If there are any leftover unbridged interfaces and we're not in Passive mode, error out. */
-    if (config->mode != DAQ_MODE_PASSIVE && num_intfs != 0)
+    if (!afpc->instances || (config->mode != DAQ_MODE_PASSIVE && num_intfs != 0))
     {
-        snprintf(errbuf, errlen, "%s: Invalid interface specification: %s!", __FUNCTION__, afpc->device);
+        snprintf(errbuf, errlen, "%s: Invalid interface specification: '%s'!", __FUNCTION__, afpc->device);
         goto err;
     }
 
