@@ -1,4 +1,4 @@
-/* $Id: daq_ipq.c,v 1.19 2010/10/21 16:15:29 rcombs Exp $ */
+/* $Id: daq_ipq.c,v 1.20 2010/12/08 15:53:58 rcombs Exp $ */
 /*
  ** Portions Copyright (C) 1998-2010 Sourcefire, Inc.
  **
@@ -39,7 +39,7 @@
 #include "daq_api.h"
 #include "sfbpf.h"
 
-#define DAQ_MOD_VERSION  3
+#define DAQ_MOD_VERSION  4
 
 #define DAQ_TYPE (DAQ_TYPE_INTF_CAPABLE | DAQ_TYPE_INLINE_CAPABLE | \
                   DAQ_TYPE_MULTI_INSTANCE | DAQ_TYPE_NO_UNPRIV)
@@ -406,8 +406,9 @@ static int ipq_daq_set_filter (void* handle, const char* filter)
 {
     IpqImpl* impl = (IpqImpl*)handle;
     struct sfbpf_program fcode;
+    int dlt = (impl->proto == PF_INET) ? DLT_IPV4 : DLT_IPV6;
 
-    if (sfbpf_compile(impl->snaplen, DLT_RAW, &fcode, filter, 1, 0) < 0)
+    if (sfbpf_compile(impl->snaplen, dlt, &fcode, filter, 1, 0) < 0)
     {
         DPE(impl->error, "%s: failed to compile '%s'",
             __FUNCTION__, filter);
@@ -485,7 +486,9 @@ static uint32_t ipq_daq_get_capabilities (void* handle)
 
 static int ipq_daq_get_datalink_type(void *handle)
 {
-    return DLT_RAW;
+    IpqImpl* impl = (IpqImpl*)handle;
+    int dlt = (impl->proto == PF_INET) ? DLT_IPV4 : DLT_IPV6;
+    return dlt;
 }
 
 static const char* ipq_daq_get_errbuf (void* handle)
