@@ -1,4 +1,4 @@
-/* $Id: daq_nfq.c,v 1.18 2010/10/21 16:15:29 rcombs Exp $ */
+/* $Id: daq_nfq.c,v 1.19 2010/12/08 15:53:58 rcombs Exp $ */
 /*
  ** Portions Copyright (C) 1998-2010 Sourcefire, Inc.
  **
@@ -39,7 +39,7 @@
 #include "daq_api.h"
 #include "sfbpf.h"
 
-#define DAQ_MOD_VERSION  3
+#define DAQ_MOD_VERSION  4
 
 #define DAQ_NAME "nfq"
 #define DAQ_TYPE (DAQ_TYPE_INTF_CAPABLE | DAQ_TYPE_INLINE_CAPABLE | \
@@ -102,10 +102,11 @@ static int nfq_daq_get_protos (const char* s)
 
     if ( !strncasecmp(s, "ip6", 3) )
         return 0x2;
-
+#if 0
+    // doesn't look like both can be handled simultaneously
     if ( !strncasecmp(s, "ip*", 3) )
         return 0x3;
-
+#endif
     return 0;
 }
 
@@ -552,8 +553,9 @@ static int nfq_daq_set_filter (void* handle, const char* filter)
 {
     NfqImpl* impl = (NfqImpl*)handle;
     struct sfbpf_program fcode;
+    int dlt = IP4(impl) ? DLT_IPV4 : DLT_IPV6;
 
-    if (sfbpf_compile(impl->snaplen, DLT_RAW, &fcode, filter, 1, 0) < 0)
+    if (sfbpf_compile(impl->snaplen, dlt, &fcode, filter, 1, 0) < 0)
     {
         DPE(impl->error, "%s: failed to compile bpf '%s'",
             __FUNCTION__, filter);
@@ -631,7 +633,9 @@ static uint32_t nfq_daq_get_capabilities (void* handle)
 
 static int nfq_daq_get_datalink_type(void *handle)
 {
-    return DLT_RAW;
+    NfqImpl* impl = (NfqImpl*)handle;
+    int dlt = IP4(impl) ? DLT_IPV4 : DLT_IPV6;
+    return dlt;
 }
 
 static const char* nfq_daq_get_errbuf (void* handle)
